<?php defined('ABSPATH') or die("No script kiddies please!");
/**
* Plugin Name: Extras for WP Rocket
* Plugin URI:  https://wordpress.org/plugins/search/extra-wp-rocket/
* Description: Added extra options to your WP Rocket configuration
* Version: 1.2
* Author: Aphotrax
* Author URI: https://aphotrax.eu/?utm_medium=referral&utm_campaign=plugin&utm_content=wpr-extra
* License:     GPL2
* License URI: https://www.gnu.org/licenses/gpl-2.0.html
* Text Domain: extra-wp-rocket
*/

if( !function_exists('is_plugin_active') ) {
	include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
}

function rocket_extra_unactive_notice() {
    if(current_user_can('activate_plugins')){
        ?><div class="notice notice-error">
            <p><?php _e('You need to have', 'extra-wp-rocket'); ?> <a href="https://wp-rocket.me" target="_blank">WP Rocket</a> <?php _e('installed and activated to use the Extras for WP Rocket plugin.', 'extra-wp-rocket'); ?></p>
        </div><?php
    }
}
if(!is_plugin_active('wp-rocket/wp-rocket.php')) {
    add_action( 'admin_notices', 'rocket_extra_unactive_notice' );
}
function rocket_extra_delete_gzstatic(){
        function directory_loop($dir){
        	$di = new RecursiveDirectoryIterator($dir);
        	foreach (new RecursiveIteratorIterator($di) as $filename => $file) {
        		if (strpos($filename, '.gz') !== false) {
            		unlink($filename);
            	}
            }
        }
        $dirs = array(WP_CONTENT_DIR."/cache/busting",WP_CONTENT_DIR."/cache/critical-css",WP_CONTENT_DIR."/cache/min");
	    foreach($dirs as $dir){ if(file_exists($dir)){ directory_loop($dir); }}
	    update_option('rocket_extra_gzlaststatic', '0');
}

function rocket_extra_plugin_action_links ( $links ) {
		$mylinks = array(
			'<a href="' . menu_page_url("rocket-extra-settings", false) . '">Settings</a>',
		);
	return array_merge( $links, $mylinks );
}
add_filter( 'plugin_action_links_' . plugin_basename(__FILE__), 'rocket_extra_plugin_action_links' );

function rocket_extra_load(){
	function rocket_extra_activate_notice() {
	    if(current_user_can('activate_plugins')){
			delete_option('rocket_extra_alert_activation');
	        ?><div class="notice notice-info">
			<p><?php _e('To enable extra WP Rocket features, please visit the ', 'extra-wp-rocket'); ?><a href="<?php menu_page_url("rocket-extra-settings", true); ?>"><?php _e('settings page', 'extra-wp-rocket'); ?></a>.</p>
	        </div><?php
	    }
	}
	if(get_option('rocket_extra_alert_activation') == 1) {
	    add_action( 'admin_notices', 'rocket_extra_activate_notice' );
	}
	
	function rocket_extra_preload_notice() {
	    if(current_user_can('activate_plugins')){
			if(get_transient('rocket_preload_complete') AND (!isset($_GET['page']) OR $_GET['page'] != 'wprocket')) {
	        	?><div class="notice notice-success">
				<p><?php _e('Preload: ', 'extra-wp-rocket'); echo get_transient('rocket_preload_complete'); _e(' pages have been cached', 'extra-wp-rocket'); ?>.</p>
	        	</div><?php delete_transient('rocket_preload_complete');
	    	}elseif(get_transient('rocket_preload_running') AND (!isset($_GET['page']) OR $_GET['page'] != 'wprocket')) {
	        	?><div class="notice notice-info">
				<p><?php _e('Preload: ', 'extra-wp-rocket'); echo get_transient('rocket_preload_running'); _e(' uncached pages have now been preloaded', 'extra-wp-rocket'); ?>.</p>
	        	</div><?php
	    	}
		}
	}
	if(get_option('rocket_extra_option_preload') == 1) {
	    add_action( 'admin_notices', 'rocket_extra_preload_notice' );
	}


	function rocket_extra_preload_interval() {
	    	return absint( get_option('rocket_extra_preload_interval','250') ) * 1000;
	}
	if(get_option('rocket_extra_option_preload_interval') == 1) {
		add_filter( 'pre_get_rocket_option_sitemap_preload_url_crawl', __NAMESPACE__ . '\rocket_extra_preload_interval' );
	}

	function rocket_extra_hideimagify(){
		echo '<style>#wpr-nav-imagify{ display: none; }</style>';
	}
	if(get_option('rocket_extra_option_hideimagify') == 1 AND isset($_GET['page']) AND $_GET['page'] == 'wprocket') {
	    add_action( 'wp_print_scripts', 'rocket_extra_hideimagify' );
	}
		
    if(!is_admin() && get_option('rocket_extra_option_gzlevel') == 1){
        function rocket_extra_gzlevel_filter($string) {
            return get_option('rocket_extra_gzlevel', '3');
        }
        add_filter( 'rocket_gzencode_level_compression', 'rocket_extra_gzlevel_filter', 10, 3 );
    }
	
    if(get_option('rocket_extra_option_gzstatic') == 1){
        $cronseconds = array("3600"=>"","3600"=>"hourly","43200"=>"twicedaily","86400"=>"daily");
        if(get_option('rocket_extra_gzlaststatic','1') < (time()-array_search(get_option('rocket_extra_gzcron','hourly'),$cronseconds))){
        
        	function rocket_extra_cronrun_notice() {
	            if(current_user_can('activate_plugins')){
	                ?><div class="notice notice-success">
		        	<p><?php _e('Your gzip css/js have been delete and new pre-compressed files have been generated', 'extra-wp-rocket'); ?>.</p>
	                </div><?php
	            }
	        }
	        if(get_option('rocket_extra_gzlaststatic')  == 1) {
	            add_action( 'admin_notices', 'rocket_extra_cronrun_notice' );
	        }
	
            function rocket_extra_do_gz($orgfile){
	            $gzfile = $orgfile.".gz";
	            $fp = gzopen ($gzfile, "wb".get_option('rocket_extra_gzlevel', '3'));
	            gzwrite ($fp, file_get_contents($orgfile));
	            gzclose($fp);
            }

            function directory_loop($dir){
            	$di = new RecursiveDirectoryIterator($dir);
            	foreach (new RecursiveIteratorIterator($di) as $filename => $file) {
            		if (strpos($filename, '.gz') !== false) {
            			if(filectime($filename) < filectime(substr($filename, 0, -3)) OR file_exists(substr($filename, 0, -3)) == FALSE){
        	    			unlink($filename);
        			    }
        		    }elseif((strpos($filename, '.js') !== false OR strpos($filename, '.css') !== false) AND file_exists($filename.".gz") == FALSE){
        			    rocket_extra_do_gz($filename);
        		    }
        	    }
            }

            $dirs = array(WP_CONTENT_DIR."/cache/busting",WP_CONTENT_DIR."/cache/critical-css",WP_CONTENT_DIR."/cache/min");
	        foreach($dirs as $dir){ if(file_exists($dir)){ directory_loop($dir); }}
	        update_option('rocket_extra_gzlaststatic', time());
        }
    }
	
    if(get_option('rocket_extra_option_gzstatic') != 1 AND get_option('rocket_extra_gzlaststatic','1') > 0){
        rocket_extra_delete_gzstatic();
    }
	if(get_option('rocket_extra_option_gzlevel') != 1 AND get_option('rocket_extra_gzlevel','1') != 3){
        update_option('rocket_extra_gzlevel', '3');
    }
	
    if(get_option('rocket_extra_option_disqus') == 1 AND is_plugin_active('disqus-comment-system/disqus.php')) {
    	if(!is_user_logged_in()){
	    	remove_action('clean_post_cache', 'rocket_clean_post' );
	    }
	    remove_action('wp_update_comment_count', 'rocket_clean_post' );
    }
	
    function rocket_extra_admin(){
		if(isset($_GET['rungzcron'])){
		    rocket_extra_delete_gzstatic();
	        update_option('rocket_extra_gzlaststatic', '1');
	        wp_redirect(menu_page_url("rocket-extra-settings", false));
		}
        ?><div class="wrap">
            <h1><?php _e('Extras for WP Rocket | Settings', 'extra-wp-rocket'); ?></h1><br>
            <form method="post" action="options.php"> 
        <?php settings_fields( 'rocket-extra-settings' ); ?>
        <?php do_settings_sections( 'rocket-extra-settings' ); ?>
				<style>@media only screen and (max-width: 650px) { td{ display: block; width: 100%;} td.checkcenter{text-align: center;} } </style>
            <table class="widefat" style="max-width: 650px;">
                <thead><tr>
                    <th colspan="3" style="font-weight: bold;"><?php _e('Enable or disable features', 'extra-wp-rocket'); ?></th>
                </tr></thead><tbody>
                <tr>
                    <td style="white-space: nowrap;"><?php _e('Custom gzip compression level:', 'extra-wp-rocket'); ?></td>
                    <td class="checkcenter"><input type="checkbox" name="rocket_extra_option_gzlevel" value="1" <?php if(get_option('rocket_extra_option_gzlevel') == 1){ echo "checked"; } ?>></td>
                    <td style="font-style: italic;"><?php _e('When you enable this feature you can increase or lower the gzip compression level that is used for your pre-compressed pages and static content.', 'extra-wp-rocket'); ?></td>
                </tr>
                <tr>
                    <td style="white-space: nowrap;"><?php _e('Pre-gzip static js/css files:', 'extra-wp-rocket'); ?></td>
                    <td class="checkcenter"><input type="checkbox" name="rocket_extra_option_gzstatic" value="1" <?php if(get_option('rocket_extra_option_gzstatic') == 1){ echo "checked"; } ?>></td>
                    <td style="font-style: italic;"><?php _e('Only a best practice when using nginx with the <a href="http://nginx.org/en/docs/http/ngx_http_gzip_static_module.html" target="_blank">gzip_static</a> module activated. For Apache you can do the same with custom rules in your htaccess file, but the overhead is not worth the performance gain.', 'extra-wp-rocket'); ?></td>
                </tr>
                <?php $checkpreload = get_option('wp_rocket_settings',''); if(isset($checkpreload['manual_preload']) AND $checkpreload['manual_preload'] == 1) { ?>
                <tr>
                    <td style="white-space: nowrap;"><?php _e('Show preload status:', 'extra-wp-rocket'); ?></td>
                    <td class="checkcenter"><input type="checkbox" name="rocket_extra_option_preload" value="1" <?php if(get_option('rocket_extra_option_preload') == 1){ echo "checked"; } ?>></td>
                    <td style="font-style: italic;"><?php _e('Enable this option to show the preload status on all admin pages (admin only).', 'extra-wp-rocket'); ?></td>
                </tr>
                <tr>
                    <td style="white-space: nowrap;"><?php _e('Change preload interval:', 'extra-wp-rocket'); ?></td>
                    <td class="checkcenter"><input type="checkbox" name="rocket_extra_option_preload_interval" value="1" <?php if(get_option('rocket_extra_option_preload_interval') == 1){ echo "checked"; } ?>></td>
                    <td style="font-style: italic;"><?php _e('Enable this option to change the preload interval to change the preload speed.', 'extra-wp-rocket'); ?></td>
                </tr>
                <?php } ?>
                <tr>
                    <td style="white-space: nowrap;"><?php _e('Hide imagify:', 'extra-wp-rocket'); ?></td>
                    <td class="checkcenter"><input type="checkbox" name="rocket_extra_option_hideimagify" value="1" <?php if(get_option('rocket_extra_option_hideimagify') == 1){ echo "checked"; } ?>></td>
                    <td style="font-style: italic;"><?php _e('Enable this option to hide the imagify tab on the WP Rocket settings page.', 'extra-wp-rocket'); ?></td>
                </tr>
                <?php if(is_plugin_active('disqus-comment-system/disqus.php')) { ?>
                <tr>
                    <td style="white-space: nowrap;"><?php _e('Disqus disable cache purge:', 'extra-wp-rocket'); ?></td>
                    <td class="checkcenter"><input type="checkbox" name="rocket_extra_option_disqus" value="1" <?php if(get_option('rocket_extra_option_disqus') == 1){ echo "checked"; } ?>></td>
                    <td style="font-style: italic;"><?php _e('This features prevents the purging of a post/page on a new comment. Could cause an incorrect comment count to be displayed until cache has expired.', 'extra-wp-rocket'); ?></td>
                </tr>
                <?php } ?>
                </tbody>
				<?php if(get_option('rocket_extra_option_gzstatic') == 1 OR get_option('rocket_extra_option_gzlevel') == 1){ ?>
                <thead><tr>
                    <th colspan="3" style="font-weight: bold;"><?php _e('Feature settings', 'extra-wp-rocket'); ?></th>
                </tr></thead>
				<?php } ?>
				<tbody><?php if(get_option('rocket_extra_option_gzlevel') == 1){ ?>
                <tr>
                    <td style="white-space: nowrap;"><?php _e('Gzip compression level:', 'extra-wp-rocket'); ?></td>
                    <td class="checkcenter"><select name="rocket_extra_gzlevel">
                    <?php for($i=1; $i<=9; $i++){
                        echo '<option value="'.$i.'"';
                        if((get_option('rocket_extra_gzlevel', '3') == '' AND $i == '3') OR get_option('rocket_extra_gzlevel', '3') == $i){ echo " SELECTED"; }
                        echo ">".$i."</option>";
                        }
                    ?></select></td>
                    <td style="font-style: italic;"><?php _e('Default is level 3.', 'extra-wp-rocket'); ?></td>
               </tr><?php } if(get_option('rocket_extra_option_preload_interval') == 1){ ?>
                <tr>
                    <td style="white-space: nowrap;"><?php _e('Preload interval:', 'extra-wp-rocket'); ?></td>
                    <td class="checkcenter"><select name="rocket_extra_preload_interval">
                    <?php for($i=50; $i<=10000; $i+=50){
				if($i < '1000'){ $itext = $i.' ms'; }else{ $itext = ($i/1000).' s'; }
				if($i <= '250' OR (round($i/100) == ($i/100) AND $i > '250' AND $i < '1000') OR (round($i/1000) == ($i/1000) AND $i >= '1000')){
                        echo '<option value="'.$i.'"';
                        if((get_option('rocket_extra_preload_interval', '500') == '' AND $i == '500') OR get_option('rocket_extra_preload_interval', '500') == $i){ echo " SELECTED"; }
                        echo ">".$itext."</option>";
				}
                        }
                    ?></select></td>
                    <td style="font-style: italic;"><?php _e('Default is 500ms, .', 'extra-wp-rocket'); ?></td>
               </tr><?php } if(get_option('rocket_extra_option_gzstatic') == 1){ ?>
                <tr>
                    <td style="white-space: nowrap;"><?php _e('Compression frequency:', 'extra-wp-rocket'); ?></td>
                    <td class="checkcenter"><select name="rocket_extra_gzcron"><?php 
                        echo '<option value="hourly"';
                        if(get_option('rocket_extra_gzcron', 'hourly') == '' OR get_option('rocket_extra_gzcron', 'hourly') == 'hourly'){ echo " SELECTED"; }
                        echo ">".__('Hourly', 'extra-wp-rocket').'</option>';
                        echo '<option value="twicedaily"';
                        if(get_option('rocket_extra_gzcron', 'hourly') == 'twicedaily'){ echo " SELECTED"; }
                        echo '>'.__('Twice daily', 'extra-wp-rocket').'</option>';
                        echo '<option value="daily"';
                        if(get_option('rocket_extra_gzcron', 'hourly') == 'daily'){ echo " SELECTED"; }
                        echo '>'.__('Daily', 'extra-wp-rocket').'</option>';
                    ?></select></td>
                    <td style="font-style: italic;"><?php _e('How often do you want to check for new static content that can be compressed? Existing files won\'t be touched, old files will be removed.', 'extra-wp-rocket'); ?> <a href="<?php menu_page_url("rocket-extra-settings", true); ?>&rungzcron=1"><?php _e('Recreate now', 'extra-wp-rocket'); ?>!</a></td>
               </tr><?php } ?></tbody>
            </table>
        <?php submit_button(); ?>
            </form>
        </div><?php
    }
	
    function register_rocket_extra_settings() {
            register_setting('rocket-extra-settings', 'rocket_extra_option_gzlevel');
            register_setting('rocket-extra-settings', 'rocket_extra_option_gzstatic');
            register_setting('rocket-extra-settings', 'rocket_extra_option_preload');
            register_setting('rocket-extra-settings', 'rocket_extra_option_preload_interval');
            register_setting('rocket-extra-settings', 'rocket_extra_option_hideimagify');
            register_setting('rocket-extra-settings', 'rocket_extra_option_disqus');
            register_setting('rocket-extra-settings', 'rocket_extra_preload_interval');
            register_setting('rocket-extra-settings', 'rocket_extra_gzlevel');
            register_setting('rocket-extra-settings', 'rocket_extra_gzcron');
    }
	
    function rocket_extra_adminmenu(){
    	if (current_user_can('activate_plugins')){
    	    add_options_page('WP Rocket Extras', 'WP Rocket Extras', 'activate_plugins', 'rocket-extra-settings', 'rocket_extra_admin');
    	    add_action('admin_init', 'register_rocket_extra_settings');
    	}
    }
    add_action('admin_menu', 'rocket_extra_adminmenu');
}

if(is_plugin_active('wp-rocket/wp-rocket.php')) {
    add_action( 'wp_rocket_loaded', 'rocket_extra_load' );
}

function rocket_extra_uninstall(){
    rocket_extra_delete_gzstatic();
    delete_option('rocket_extra_option_gzlevel');
    delete_option('rocket_extra_option_gzstatic');
    delete_option('rocket_extra_option_preload');
    delete_option('rocket_extra_option_preload_interval');
    delete_option('rocket_extra_option_hideimagify');
    delete_option('rocket_extra_option_disqus');
    delete_option('rocket_extra_gzlevel');
    delete_option('rocket_extra_gzcron');
    delete_option('rocket_extra_gzlaststatic');
    delete_option('rocket_extra_preload_interval');
    delete_option('rocket_extra_alert_activation');
}
register_uninstall_hook(__FILE__, 'rocket_extra_uninstall');

function rocket_extra_activate() {
	update_option('rocket_extra_alert_activation','1');
}
register_activation_hook( __FILE__, 'rocket_extra_activate' );
